from os import environ
from typing import Final


SECRET_KEY: Final = environ.get("OZGURSOZLUK_SECRET_KEY", "")
EKSI_SOZLUK_BASE_URL: Final = environ.get(
    "EKSI_SOZLUK_BASE_URL", "https://eksisozluk1923.com"
)

DEFAULT_THEME: Final = "light"
DEFAULT_DISPLAY_PINNED_TOPICS: Final = "true"
DEFAULT_DISPLAY_ENTRY_FAVORITE_COUNT: Final = "false"
DEFAULT_DISPLAY_ENTRY_AUTHOR: Final = "false"
DEFAULT_DISPLAY_ENTRY_DATETIME: Final = "true"

DEFAULT_COOKIES: Final = {
    "theme": DEFAULT_THEME,
    "display_pinned_topics": DEFAULT_DISPLAY_PINNED_TOPICS,
    "display_entry_favorite_count": DEFAULT_DISPLAY_ENTRY_FAVORITE_COUNT,
    "display_entry_author": DEFAULT_DISPLAY_ENTRY_AUTHOR,
    "display_entry_datetime": DEFAULT_DISPLAY_ENTRY_DATETIME,
}

THEMES: Final = [
    "light",
    "dark",
    "amoled",
    "violet",
    "gruvbox",
    "gruvboxlight",
    "discord",
    "startpage",
]



from flask import Flask

from ozgursozluk.configs import SECRET_KEY


__version__ = "0.7.5"
__source_code__ = "https://github.com/beucismis/ozgursozluk"
__description__ = "a free and open source alternative ekşi sözlük front-end"

app = Flask(__name__)
app.secret_key = SECRET_KEY


import ozgursozluk.views
